@@ -2,7 +2,7 @@ import logging
 import logging.config
 
 
+main_logger = logging.getLogger("main")
 notetype_logger = logging.getLogger("notetype")
-importer_logger = logging.getLogger("importer")
 parser_logger = logging.getLogger("parser")
 helper_logger = logging.getLogger("helper")
