@@ -1,30 +1,43 @@
 from ..helper.formatHelper import list2str
 from ..note import Note
 from ..model import Model
-from ..config import notetype_settings as settings
+from ..config import dict as conf
+from ..config import config_updater
+from ..log import notetype_logger as log
 
 
-notetype_name = "Choices"
-if notetype_name not in settings:
-    settings[notetype_name] = {}
-priority = settings[notetype_name].get("priority", 10)
+notetype_name = "QA"
+if notetype_name not in conf["notetype"]:
+    conf["notetype"][notetype_name] = {}
+settings = conf["notetype"][notetype_name]
+
+priority = None
+
+
+def update_choices_config():
+    global settings, priority
+
+    priority = settings.get("priority", 10)
+
+
+config_updater.append(update_choices_config)
 
 
 def check(lines: list) -> bool:
     return len(lines) >= 2
 
 
-def get(text: str, tags: list = []) -> Note:
-    if not check(text):
-        raise Exception("Not QA format.")
+def get(text: str, deck: str = "Export", tags: list = []) -> Note:
     lines = text.splitlines()
     front = lines[0]
     back = list2str(lines[1:], '', '\n')
     if front == "":
-        raise Exception("Blank front text, skipping.")
+        log.info("Blank front text, skipping.")
+        return
     if back == "":
-        raise Exception("Blank back text, skipping.")
-    return QANote(front, back, _tags=tags)
+        log.info("Blank back text, skipping.")
+        return
+    return QANote(front=front, back=back, deck=deck, tags=tags)
 
 
 BACK = r"""{{FrontSide}}
@@ -67,5 +80,6 @@ _model = Model(
 
 
 class QANote(Note):
-    def __init__(self, front, back, model=_model, _tags=("#Export",)):
-        super().__init__(model, {"Front": front, "Back": back}, _tags)
+    def __init__(self, front, back, model=_model, deck="Export", tags=("#Export",)):
+        super().__init__(model=model, fields={
+            "Front": front, "Back": back}, deck=deck, tags=tags)
